package com.ruoyi.baseinfo.service;

import java.util.List;
import com.ruoyi.baseinfo.domain.BaseMaterialInfo;

/**
 * 物料基础信息Service接口
 * 
 * @author CaesarBao
 * @date 2020-10-22
 */
public interface IBaseMaterialInfoService 
{
    /**
     * 查询物料基础信息
     * 
     * @param objid 物料基础信息ID
     * @return 物料基础信息
     */
    public BaseMaterialInfo selectBaseMaterialInfoById(Long objid);

    /**
     * 查询物料基础信息列表
     * 
     * @param baseMaterialInfo 物料基础信息
     * @return 物料基础信息集合
     */
    public List<BaseMaterialInfo> selectBaseMaterialInfoList(BaseMaterialInfo baseMaterialInfo);

    /**
     * 新增物料基础信息
     * 
     * @param baseMaterialInfo 物料基础信息
     * @return 结果
     */
    public int insertBaseMaterialInfo(BaseMaterialInfo baseMaterialInfo);

    /**
     * 修改物料基础信息
     * 
     * @param baseMaterialInfo 物料基础信息
     * @return 结果
     */
    public int updateBaseMaterialInfo(BaseMaterialInfo baseMaterialInfo);

    /**
     * 批量删除物料基础信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBaseMaterialInfoByIds(String ids);

    /**
     * 删除物料基础信息信息
     * 
     * @param objid 物料基础信息ID
     * @return 结果
     */
    public int deleteBaseMaterialInfoById(Long objid);
}
